<?php
/**
 * Team widget.
 *
 * @package Restaurantz
 */

class Restaurantz_Team_Widget extends SiteOrigin_Widget {

	function __construct() {

		parent::__construct(
			'restaurantz-team',
			__( 'Restaurantz: Team', 'restaurantz' ),
			array(
				'description' => __( 'Displays team member carousel', 'restaurantz' ),
			),
			array(),
			array(
				'title' => array(
					'type'  => 'text',
					'label' => __( 'Title', 'restaurantz' ),
				),
				'sub_title' => array(
					'type'  => 'text',
					'label' => __( 'Subtitle', 'restaurantz' ),
				),
				'members' => array(
					'type'       => 'repeater',
					'label'      => __( 'Members', 'restaurantz' ),
					'item_name'  => __( 'Member', 'restaurantz' ),
					'item_label' => array(
						'selector'     => "[id*='members-full_name']",
						'update_event' => 'change',
						'value_method' => 'val',
					),
					'fields' => array(
						'full_name' => array(
							'type'  => 'text',
							'label' => __( 'Full Name', 'restaurantz' ),
						),
						'position' => array(
							'type'  => 'text',
							'label' => __( 'Position', 'restaurantz' ),
						),
						'profile_picture' => array(
							'type'     => 'media',
							'library'  => 'image',
							'label'    => __( 'Image', 'restaurantz' ),
							'fallback' => true,
						),
						'social_links' => array(
							'type'   => 'repeater',
							'label'  => __( 'Social Links', 'restaurantz' ),
							'fields' => array(
								'social_icon' => array(
									'type'  => 'icon',
									'label' => __( 'Icon', 'restaurantz' ),
								),
								'social_url' => array(
									'type'  => 'text',
									'label' => __( 'URL', 'restaurantz' ),
								),
							),
						),
					),
				),
				'per_row' => array(
					'type'    => 'select',
					'label'   => __( 'Teams per row', 'restaurantz' ),
					'default' => 3,
					'options' => array(
						'1' => 1,
						'2' => 2,
						'3' => 3,
						'4' => 4,
					),
				),
				'settings_color' => array(
					'type'   => 'section',
					'label'  => __( 'Color Settings', 'restaurantz' ),
					'hide'   => true,
					'fields' => array(
						'color_widget_title' => array(
							'type'    => 'color',
							'label'   => __( 'Widget Title Color', 'restaurantz' ),
							'default' => '#562c19',
						),
						'color_widget_sub_title' => array(
							'type'    => 'color',
							'label'   => __( 'Widget Subtitle Color', 'restaurantz' ),
							'default' => '#313131',
						),
						'color_team_member_name' => array(
							'type'    => 'color',
							'label'   => __( 'Team Title Color', 'restaurantz' ),
							'default' => '#313131',
						),
						'color_team_member_designation' => array(
							'type'    => 'color',
							'label'   => __( 'Team Designation Color', 'restaurantz' ),
							'default' => '#313131',
						),
						'color_social_links' => array(
							'type'    => 'color',
							'label'   => __( 'Social Links Color', 'restaurantz' ),
							'default' => '#313131',
						),
						'color_social_links_hover' => array(
							'type'    => 'color',
							'label'   => __( 'Social Links Hover Color', 'restaurantz' ),
							'default' => '#fff',
						),
						'color_social_links_background' => array(
							'type'    => 'color',
							'label'   => __( 'Social Links Background Color', 'restaurantz' ),
							'default' => '#dddddd',
						),
						'color_social_links_background_hover' => array(
							'type'    => 'color',
							'label'   => __( 'Social Links Hover Background Color', 'restaurantz' ),
							'default' => '#7f390a',
						),
	    			),
				),
			)
		);
	}

	function get_style_name( $instance ) {
		return 'default';
	}

	function get_template_name( $instance ) {
		return 'default';
	}

	function get_less_variables( $instance ) {

		$less_vars = array();
		if ( ! empty( $instance['settings_color']['color_widget_title'] ) ) {
			$less_vars['color_widget_title'] = $instance['settings_color']['color_widget_title'];
		}
		if ( ! empty( $instance['settings_color']['color_widget_sub_title'] ) ) {
			$less_vars['color_widget_sub_title'] = $instance['settings_color']['color_widget_sub_title'];
		}
		if ( ! empty( $instance['settings_color']['color_team_member_name'] ) ) {
			$less_vars['color_team_member_name'] = $instance['settings_color']['color_team_member_name'];
		}
		if ( ! empty( $instance['settings_color']['color_team_member_designation'] ) ) {
			$less_vars['color_team_member_designation'] = $instance['settings_color']['color_team_member_designation'];
		}
		if ( ! empty( $instance['settings_color']['color_social_links'] ) ) {
			$less_vars['color_social_links'] = $instance['settings_color']['color_social_links'];
		}
		if ( ! empty( $instance['settings_color']['color_social_links_hover'] ) ) {
			$less_vars['color_social_links_hover'] = $instance['settings_color']['color_social_links_hover'];
		}
		if ( ! empty( $instance['settings_color']['color_social_links_background'] ) ) {
			$less_vars['color_social_links_background'] = $instance['settings_color']['color_social_links_background'];
		}
		if ( ! empty( $instance['settings_color']['color_social_links_background_hover'] ) ) {
			$less_vars['color_social_links_background_hover'] = $instance['settings_color']['color_social_links_background_hover'];
		}
		return $less_vars;

	}
}

siteorigin_widget_register( 'restaurantz-team', __FILE__, 'Restaurantz_Team_Widget' );
